#! /usr/bin/python

### References
###
### Grayson, J. "Python and Tkinter Programming" Manning, 2000.
### Chapter 3: calc1.py, calc2.py
###
### Padding so that 'from Tkinter import *'
### is on line 15
### (like 'import wx'in myWxCalc.py)
###
###
###

from Tkinter import *
from myCalc import AbstractCalculator

class TkCalc(Frame, AbstractCalculator):
    keysym2label = {'plus': '+',
                    'minus': '-',
                    'asterisk': '*',
                    'period': '.',
                    'slash': '/',
                    'equal': '=',
                    'Return': '=',
                    'Delete': 'C',
                    'BackSpace': 'C',
                    'q': 'OFF'
                    }
    
    def __init__(self, debug=False):
        # init
        AbstractCalculator.__init__(self, debug)

        # main frame
        Frame.__init__(self)
        self.pack(expand=NO, fill=NONE)
        self.master.title('Simple Tk Calc')
        self.master.resizable(0,0)

        # display
        self._display = StringVar()
        self._display.set('0')
        # Label insisted on central justification
    	Entry(self, justify=RIGHT, relief=SUNKEN,
              disabledforeground='black',
              disabledbackground='white',
              state=DISABLED, 
              textvariable=self._display).pack(side=TOP, expand=YES, fill=BOTH)

        # keys
        for row in self.keyLayout:
            rowFrame = Frame(self)
            for key in row:
                Button(rowFrame, text=key,
                       command=lambda k=key: self.keyAction(k),
                       width=4).pack(side=LEFT, expand=NO, fill=NONE)
            rowFrame.pack(side=TOP, expand=YES, fill=BOTH)

        # key bindings
        self.bind('<KeyPress>', self.buttonPress)
        self.focus_set()

        # go
        self.mainloop()

    def getDisplay(self):
        return self._display.get()

    def setDisplay(self, value):
        self._display.set(value)

    display = property(getDisplay, setDisplay)

    def quitApp(self):
        self.quit()

    def buttonPress(self, event):
        k = event.keysym
        if self.debug:
            print 'MyTkCalc::buttonPress:\tk: %s' % k
        if k not in '1234567890':
            k = self.keysym2label.get(k)
        self.keyAction(k)


if __name__ == '__main__':
    TkCalc(True)
